unit fMain;

interface

uses
  Windows, Messages, Controls, SysUtils, Graphics, Forms, Jpeg, ExtCtrls, StdCtrls;

type
  TForm1 = class(TForm)
    procedure FormCreate(Sender: TObject);
  private
    P: TControl;
    _OLD_WindowProc_: TWndMethod;
    function CreateImage(var image: TImage): Boolean;
    function ShowContent(const FileName: string): TControl;
    function ShowBmp(const FileName: string): TControl;
    function ShowJpg(const FileName: string): TControl;
    function ShowTxt(const FileName: string): TControl;
  protected
    procedure FormWindowProc (var Msg: TMessage);
    procedure FilesDrop(Msg: TWMDropFiles) ;
  end;

var
  Form1: TForm1;

implementation

uses ShellApi;

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
  P := nil;
  WindowState := wsMaximized;
  if ParamCount > 0 then
    ShowContent(ParamStr(1));

  _OLD_WindowProc_ := WindowProc;
  WindowProc := FormWindowProc;
  DragAcceptFiles(Handle, True) ;
end;

function TForm1.ShowContent(const FileName: string): TControl;
var
  ext: string;
begin
  if FileExists(FileName) then
  begin
    if P <> nil then FreeAndNil(P);
    ext := LowerCase(ExtractFileExt(FileName));
          if ext = '.bmp'   then P := ShowBmp(FileName)
    else  if ext = '.jpg'   then P := ShowJpg(FileName)
    else  if ext = '.jpeg'  then P := ShowJpg(FileName)
    else  if ext = '.txt'   then P := ShowTxt(FileName);
  end;
  Result := P;
end;

function TForm1.CreateImage(var image: TImage): Boolean;
begin
  image := TImage.Create(Self);
  image.Parent := Self;
  image.Align := alClient;
  image.Stretch := True;
  Result := image <> nil;
end;

function TForm1.ShowBmp(const FileName: string): TControl;
var
  image: TImage;
begin
  Result := nil;
  if FileExists(FileName) and
     CreateImage(image)   then
  begin
    image.Picture.LoadFromFile(FileName);
    Result := image;
  end;
end;

function TForm1.ShowJpg(const FileName: string): TControl;
var
  g: TJPEGImage;
  image: TImage;
begin
  Result := nil;
  if FileExists(FileName) and
     CreateImage(image)   then
  begin
    g := TJPEGImage.Create;
    try
      g.LoadFromFile(FileName);
      image.Picture.Assign(g);
    finally
      FreeAndNil(g);
    end;
    Result := image;
  end;
end;

function TForm1.ShowTxt(const FileName: string): TControl;
begin
  Result := nil;
  if FileExists(FileName) then
  begin
    Result := TListBox.Create(Self);
    with TListBox(Result) do
    begin
      Parent := Self;
      Align := alClient;
      Items.LoadFromFile(FileName);
    end;
  end;
end;

procedure TForm1.FilesDrop(Msg: TWMDropFiles);
var
  n: Longint;
  fn: array[0..255] of Char;
begin
  FillChar(fn, SizeOf(fn), 0);
  n := DragQueryFile(Msg.Drop, $FFFFFFFF, nil, 0);
  if n = 1 then //u঳@ɮ
    if DragQueryFile(Msg.Drop, 0, @fn, sizeof(fn)) > 0 then
      ShowContent(Trim(fn));
end;

procedure TForm1.FormWindowProc(var Msg: TMessage);
begin
  if Msg.Msg = WM_DROPFILES then FilesDrop(TWMDropFiles(Msg))
  else                           _OLD_WindowProc_(Msg) ;
end;

end.
